==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fi.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Haluatko lisätä etäjaon {name} kohteesta {owner}@{remote}?",
    "Remote share" : "Etäjako",
    "Remote share password" : "Etäjaon salasana",
    "Cancel" : "Peruuta",
    "Add remote share" : "Lisää etäjako",
    "Copy" : "Kopioi",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "Invalid Federated Cloud ID" : "Virheellinen federoidun pilven tunniste",
    "Server to server sharing is not enabled on this server" : "Palvelimien kesken jakaminen ei ole käytössä tällä palvelimella",
    "Couldn't establish a federated share." : "Ei voinut muodostaa federoitua jakoa.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Ei voinut muodostaa federoitua jakoa. Ehkä salasana oli väärin.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federoidun jakamisen pyyntö lähetetty, saat kutsun. Tarkista ilmoitukset.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Federoitua jakoa ei voitu muodostaa. Vaikuttaa siltä, että palvelin jonka kanssa federointia yritetään, on versioltaan liian vanha (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Federoitujen ryhmäjakojen lähettäminen tältä palvelimelta ei ole sallittu.",
    "Not allowed to create a federated share with the same user" : "Saman käyttäjän kanssa ei ole sallittua luoda federoitua jakoa",
    "File is already shared with %s" : "Tiedosto on jo jaettu kohteen %s kanssa",
    "Could not find share" : "Ei löytynyt jakoa",
    "Federated sharing" : "Federoitu jakaminen",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vastaanotit jaon {share} etäjakona käyttäjältä {user} ({behalf}:n puolesta)",
    "You received {share} as a remote share from {user}" : "Vastaanotit jaon {share} etäjakona käyttäjältä {user}",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Jaa kanssani käyttäen #Nextcloud ja federoitua pilvitunnistetta, katso %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Jaa kanssani käyttäen #Nextcloud ja federoitua pilvitunnistetta",
    "Sharing" : "Jakaminen",
    "Federated file sharing" : "Federoitu tiedostojako",
    "Provide federated file sharing across servers" : "Mahdollistaa federoidun tiedostojaon palvelinten välillä",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "Open documentation" : "Avaa ohje",
    "Adjust how people can share between servers." : "Mukauta kuinka ihmiset voivat jakaa palvelinten välillä.",
    "Allow users on this server to receive shares from other servers" : "Salli tämän palvelimen käyttäjien vastaanottaa jakoja muilta palvelimilta",
    "Allow users on this server to send shares to groups on other servers" : "Salli käyttäjien tällä palvelimella lähettää jakoja toisten palvelimien ryhmille",
    "Allow users on this server to receive group shares from other servers" : "Salli käyttäjien tällä palvelimella vastaanottaa ryhmäjakoja toisilta palvelimilta",
    "Search global and public address book for users" : "Etsi käyttäjiä maailmanlaajuisesta ja julkisesta osoitekirjasta",
    "Allow users to publish their data to a global and public address book" : "Salli käyttäjien julkaista tietojaan maailmanlaajuisessa ja julkisessa osoitekirjassa",
    "Federated Cloud" : "Federoitu pilvi",
    "Your Federated Cloud ID:" : "Federoidun pilvesi tunniste:",
    "Share it so your friends can share files with you:" : "Jaa se, jotta ystäväsi voivat jakaa tiedostoja kanssasi:",
    "Add to your website" : "Lisää verkkosivuillesi",
    "Share with me via Nextcloud" : "Jaa kanssani Nextcloudin kautta",
    "HTML Code:" : "HTML-koodi:",
    "Allow users on this server to send shares to other servers" : "Salli tämän palvelimen käyttäjien lähettää jakoja muille palvelimille"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fi.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Virheellinen federoidun pilven tunniste",
    "Server to server sharing is not enabled on this server" : "Palvelimien kesken jakaminen ei ole käytössä tällä palvelimella",
    "Couldn't establish a federated share." : "Ei voinut muodostaa federoitua jakoa.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Ei voinut muodostaa federoitua jakoa. Ehkä salasana oli väärin.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federoidun jakamisen pyyntö lähetetty, saat kutsun. Tarkista ilmoitukset.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Federoitua jakoa ei voitu muodostaa. Vaikuttaa siltä, että palvelin jonka kanssa federointia yritetään, on versioltaan liian vanha (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Federoitujen ryhmäjakojen lähettäminen tältä palvelimelta ei ole sallittu.",
    "Federated shares require read permissions" : "Federoidut jaot vaativat lukuoikeuksia",
    "File is already shared with %s" : "Tiedosto on jo jaettu kohteen %s kanssa",
    "Could not find share" : "Ei löytynyt jakoa",
    "Federated sharing" : "Federoitu jakaminen",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vastaanotit jaon {share} etäjakona käyttäjältä {user} ({behalf}:n puolesta)",
    "You received {share} as a remote share from {user}" : "Vastaanotit jaon {share} etäjakona käyttäjältä {user}",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "Sharing" : "Jakaminen",
    "Federated file sharing" : "Federoitu tiedostojako",
    "Provide federated file sharing across servers" : "Mahdollistaa federoidun tiedostojaon palvelinten välillä",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Jaa kanssani käyttäen #Nextcloud ja federoitua pilvitunnistetta",
    "Share with me via Nextcloud" : "Jaa kanssani Nextcloudin kautta",
    "Copy" : "Kopioi",
    "Copied!" : "Kopioitu!",
    "Federated Cloud" : "Federoitu pilvi",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Voit jakaa kenelle tahansa, joka käyttää Nextcloud-palvelinta tai muuta Open Cloud Mesh (OCM) -yhteensopivaa palvelinta tai palvelua! Kirjoita heidän federoidun pilven tunniste jaon kohteeksi. Se on muodossa henkilö@cloud.example.com",
    "Share it so your friends can share files with you:" : "Jaa se, jotta ystäväsi voivat jakaa tiedostoja kanssasi:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (aiemmin Twitter)",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Lisää verkkosivuillesi",
    "HTML Code:" : "HTML-koodi:",
    "Cancel" : "Peruuta",
    "Add remote share" : "Lisää etäjako",
    "Remote share" : "Etäjako",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Haluatko lisätä etäjaon {name} kohteesta {owner}@{remote}?",
    "Remote share password" : "Etäjaon salasana",
    "Copy to clipboard" : "Kopioi leikepöydälle"
},
"nplurals=2; plural=(n != 1);");
